package com.ruoyi.bst.credit.mapper;

import java.math.BigDecimal;
import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.credit.domain.Credit;
import com.ruoyi.bst.credit.domain.CreditQuery;
import com.ruoyi.bst.credit.domain.CreditVO;

/**
 * 挂账方Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-27
 */
public interface CreditMapper
{
    /**
     * 查询挂账方
     *
     * @param id 挂账方主键
     * @return 挂账方
     */
    CreditVO selectCreditById(Long id);

    /**
     * 查询挂账方列表
     *
     * @param query 挂账方
     * @return 挂账方集合
     */
    List<CreditVO> selectCreditList(@Param("query")CreditQuery query);

    /**
     * 新增挂账方
     *
     * @param credit 挂账方
     * @return 结果
     */
    int insertCredit(Credit credit);

    /**
     * 批量新增挂账方
     */
    int batchInsert(@Param("list") List<? extends Credit> list);

    /**
     * 批量修改挂账方
     */
    int batchUpdate(@Param("list") List<? extends Credit> list);

    /**
     * 修改挂账方
     *
     * @param credit 挂账方
     * @return 结果
     */
    public int updateCredit(@Param("data") Credit credit);

    /**
     * 删除挂账方
     *
     * @param id 挂账方主键
     * @return 结果
     */
    int deleteCreditById(Long id);

    /**
     * 批量删除挂账方
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCreditByIds(Long[] ids);

    /**
     * 逻辑删除挂账方
     *
     * @param ids 需要删除的挂账方主键
     * @return 结果
     */
    int logicDel(@Param("ids") List<Long> ids);

    /**
     * 查询挂账方ID列表
     * @param query
     * @return
     */
    List<Long> selectIdList(@Param("query") CreditQuery query);

    /**
     * 增加已使用金额
     * @param id id
     * @param amount 金额
     * @return
     */
    int addUsedAmount(@Param("id") Long id, @Param("amount") BigDecimal amount);
}
